==> jmb.fax-0.5.5.tar.gz: jmb.fax-0.5.5/setup.py <==
# http://www.28lines.com/?p=8
import os
import re
import sys
from setuptools import setup, find_packages
from setuptools.command.test import test


class TestRunner(test):

    def run(self, *args, **kwargs):
        if self.distribution.install_requires:
            self.distribution.fetch_build_eggs(
                self.distribution.install_requires)
        if self.distribution.tests_require:
            self.distribution.fetch_build_eggs(
                self.distribution.tests_require)
        from jmb.fax.tests.runtests import runtests
        runtests()


def get_data_files(*args, **kwargs):

    EXT_PATTERN = kwargs.get('ext') or '\.(html|js|txt|css|po|mo|png|rst|odt)'

    data_dict = {}
    for pkg_name in args:
        data_files = []
        for dirpath, dirnames, filenames in os.walk(pkg_name.replace('.', '/')):
            rel_dirpath = re.sub("^" + pkg_name + '/', '',  dirpath)
            # Ignore dirnames that start with '.'
            for i, dirname in enumerate(dirnames):
                if dirname.startswith('.'):
                    del dirnames[i]
            if filenames:
                data_files += [os.path.join(rel_dirpath, f) for f in filenames
                               if re.search(EXT_PATTERN, f)]
        data_dict[pkg_name] = data_files
    return data_dict

install_requires = [
    'setuptools',
    'lxml',
    'jmb.core>=0.8.1',
    'jmb.organization>=0.2.7',
    'pytz',
    'reportlab',
    'django-autocomplete-light',
    'django-ckeditor',
]
if sys.version_info[0] == '2':
    install_requires += ['suds']
else:
    install_requires += ['suds-py3']

setup(
    name='jmb.fax',
    namespace_packages=['jmb'],
    version="0.5.5",
    url="hg.thundersystems.it/jmb/jmb.fax",
    description='JMB FAX',
    author='ThunderSystems',
    author_email='dev@thundersystems.it',
    packages=find_packages(exclude=['tests', 'tests.*']),
    platforms='any',
    zip_safe=False,
    classifiers=[
        'Environment :: Jumbo',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Framework :: Django',
        'Framework :: Jumbo',
    ],
    test_suite="jmb.fax.tests",
    cmdclass={"test": TestRunner},
    install_requires=install_requires,
    package_data=get_data_files('jmb.fax')
)

==> jmb.fax-0.5.6.tar.gz: jmb.fax-0.5.6/setup.py <==
# http://www.28lines.com/?p=8
import os
import re
import sys
from setuptools import setup, find_packages
from setuptools.command.test import test


class TestRunner(test):

    def run(self, *args, **kwargs):
        if self.distribution.install_requires:
            self.distribution.fetch_build_eggs(
                self.distribution.install_requires)
        if self.distribution.tests_require:
            self.distribution.fetch_build_eggs(
                self.distribution.tests_require)
        from jmb.fax.tests.runtests import runtests
        runtests()


def get_data_files(*args, **kwargs):

    EXT_PATTERN = kwargs.get('ext') or '\.(html|js|txt|css|po|mo|png|rst|odt)'

    data_dict = {}
    for pkg_name in args:
        data_files = []
        for dirpath, dirnames, filenames in os.walk(pkg_name.replace('.', '/')):
            rel_dirpath = re.sub("^" + pkg_name + '/', '',  dirpath)
            # Ignore dirnames that start with '.'
            for i, dirname in enumerate(dirnames):
                if dirname.startswith('.'):
                    del dirnames[i]
            if filenames:
                data_files += [os.path.join(rel_dirpath, f) for f in filenames
                               if re.search(EXT_PATTERN, f)]
        data_dict[pkg_name] = data_files
    return data_dict

install_requires = [
    'setuptools',
    'lxml',
    'jmb.core>=0.8.1',
    'jmb.organization>=0.2.7',
    'pytz',
    'reportlab',
    'django-autocomplete-light',
    'django-ckeditor',
]
if sys.version_info[0] == 2:
    install_requires += ['suds']
else:
    install_requires += ['suds-py3']

setup(
    name='jmb.fax',
    namespace_packages=['jmb'],
    version="0.5.6",
    url="hg.thundersystems.it/jmb/jmb.fax",
    description='JMB FAX',
    author='ThunderSystems',
    author_email='dev@thundersystems.it',
    packages=find_packages(exclude=['tests', 'tests.*']),
    platforms='any',
    zip_safe=False,
    classifiers=[
        'Environment :: Jumbo',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Framework :: Django',
        'Framework :: Jumbo',
    ],
    test_suite="jmb.fax.tests",
    cmdclass={"test": TestRunner},
    install_requires=install_requires,
    package_data=get_data_files('jmb.fax')
)
